﻿using Steema.TeeChart;
using Steema.TeeChart.Drawing;
using Steema.TeeChart.Styles;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Xamarin.Forms;

namespace TeeChartsSample
{
    public class App : Application
    {
        public App()
        {
            List<String> items = new List<string>()
            {
                "Chart 1", "Chart 2", "Chart 3", "Chart 4", "Chart 5", "Chart 6", "Chart 7", "Chart 8", "Chart 9", "Chart 10"
            };

            List<Color> colors = new List<Color>
            {
                Color.Red,
                Color.Blue,
                Color.Yellow,
                Color.Green,
                Color.Purple,
                Color.Aqua,
                Color.Teal,
            };
            Random r = new Random();

            ListView lv = new ListView()
            {
                VerticalOptions = LayoutOptions.FillAndExpand,
                HorizontalOptions = LayoutOptions.FillAndExpand,
                ItemsSource = items,
                RowHeight = 100,
                ItemTemplate = new DataTemplate(() =>
                {
                    // ISSUE # 1
                    // Since I am rendering one chart for each row in the listview, the listview will add a scrollable container to its children.
                    // TeeCharts do not play nice with scrollable containers on Xamarin.Forms WindowsPhone projects, so it would crash giving a NullPointerException in TeeChart.WP8.DLL.
                    Steema.TeeChart.Chart chart = new Steema.TeeChart.Chart();

                    Series s;
                    if (r.Next() % 2 == 0)
                    {
                        s = new Pie();
                        s.Marks.Font.Color = Color.Green;
                    }
                    else
                    {
                        s = new Bar();
                        s.Marks.Font.Color = Color.White;
                    }

                    s.Marks.Font.Size = 6 + (r.Next() % 11);
                    // s.Marks.Font.Color = colors[r.Next() % colors.Count];


                    s.Legend.Visible = false;
                    s.Marks.Frame.Visible = false;
                    s.Marks.Callout.Visible = false;
                    s.Marks.Transparent = true;
                    s.Marks.Arrow.Visible = false;
                    s.Marks.Style = MarksStyles.Value;

                    for (int i = 0; i < 4; i++)
                    {
                        s.Add(r.Next() % 10, "" + i);
                    }

                    ChartView chartView = new ChartView
                    {
                        VerticalOptions = LayoutOptions.Center,
                        HorizontalOptions = LayoutOptions.Center,

                        WidthRequest = 100,
                        HeightRequest = 100
                    };

                    chart.Aspect.View3D = false;
                    chart.Axes.Left.Visible = false;
                    chart.Axes.Right.Visible = false;
                    chart.Axes.Top.Visible = false;
                    chart.Axes.Bottom.Visible = false;
                    chart.Panel.Bevel.Inner = BevelStyles.None;
                    chart.Panel.Bevel.Outer = BevelStyles.None;
                    chart.Panel.Gradient.Visible = false;
                    chart.Panel.Color = Color.White;
                    chart.Panning.Allow = ScrollModes.None;
                    chart.Zoom.Allow = false;
                    chart.Walls.Visible = false;
                    chart.Panel.Color = Color.Transparent;

                    chart.Series.Add(s);
                    chart.Series[0].ColorEach = true;

                    chartView.Model = chart;

                    Label label = new Label()
                    {
                        HorizontalOptions = LayoutOptions.StartAndExpand,
                        VerticalOptions = LayoutOptions.FillAndExpand
                    };
                    label.SetBinding(Label.TextProperty, ".");

                    return new ViewCell
                    {
                        View = new StackLayout
                        {
                            Orientation = StackOrientation.Horizontal,
                            Children =
                            {
                                label,
                                chartView
                            }
                        }
                    };
                }),
            };

            // ISSUE # 2: Since I am adding this page in a navigation page, the page will have a navigation header on Android, now when I scroll the listview to view lower items in the list,
            // The marks of the items scrolling out of the view towards the top will leave trails on top of the top navigation header. 
            MainPage = new NavigationPage(new ContentPage
            {
                Content = new StackLayout
                {
                    VerticalOptions = LayoutOptions.Center,
                    Children = {
                        lv
					}
                }
            });
        }

        protected override void OnStart()
        {
            // Handle when your app starts
        }

        protected override void OnSleep()
        {
            // Handle when your app sleeps
        }

        protected override void OnResume()
        {
            // Handle when your app resumes
        }
    }
}
